@@ -1,16 +1,14 @@
 import os
+from json import dumps
 
-from flask import Blueprint, render_template, request
-from flask import redirect, make_response, url_for
+from flask import Blueprint, render_template
+from flask import make_response, url_for
 
-from grano import __version__
 from grano.lib.serialisation import jsonify
-from grano.core import app, url_for, app_name
-from grano.views.cache import validate_cache, disable_cache
-from grano.background import ping
+from grano.core import app, app_name, app_version
 
 
-UI_PREFIX = app.config.get('UI_PREFIX', '/')
+UI_PREFIX = app.config.get('UI_PREFIX', '')
 STATIC_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), '../../static'))
 
 blueprint = Blueprint('ui', __name__, template_folder=STATIC_PATH,
@@ -36,8 +34,12 @@ def index(**kw):
 @blueprint.route('/config.js')
 def config(**kw):
     api_root = app.config.get('API_ROOT') or url_for('base_api.status')
-    res = render_template('js/config.js', ui_root=UI_PREFIX,
-        api_root=api_root, app_name=app_name, app_version=__version__)
+    res = render_template('js/config.js', ui_root=url_for('ui.index'),
+        data_types=dumps(app.config['DATA_TYPES']),
+        schema_objs=dumps(app.config['SCHEMA_OBJS']),
+        api_root=api_root,
+        app_name=app_name,
+        app_version=app_version)
     res = make_response(res)
     res.headers['Content-Type'] = 'application/javascript'
     return res
