@@ -1,5 +1,6 @@
-function HomeCtrl($scope, $location, $http, $modal) {
+function HomeCtrl($scope, $location, $http, $modal, core) {
     $scope.projects = {};
+    $scope.loadProject(null);
 
     $scope.loadProjects = function(url) {
         $http.get(url).then(function(data) {
@@ -7,14 +8,15 @@ function HomeCtrl($scope, $location, $http, $modal) {
         });
     };
     
-    $scope.loadProjects('/api/1/projects');
+    $scope.loadProjects(core.call('/projects'));
 
     $scope.newProject = function(){
         var d = $modal.open({
             templateUrl: 'projects/new.html',
-            controller: 'ProjectsNewCtrl'
+            controller: 'ProjectsNewCtrl',
+            backdrop: false
         });
     };
 }
 
-HomeCtrl.$inject = ['$scope', '$location', '$http', '$modal'];
+HomeCtrl.$inject = ['$scope', '$location', '$http', '$modal', 'core'];
